@@ -20,7 +20,7 @@ ERR__command_not_allowed = "Command not allowed. Please use one of " + str(ALLOW
 
 
 HOST_POOL = {}
-HOST_USER = None
+HOST_USER = {}
 
 
 class DBPGInterface(DBInterface):
@@ -49,12 +49,14 @@ class DBPGInterface(DBInterface):
             if db_name is None:
                 db_name = ""
 
+            self.db_name = db_name
+
             if self.is_host_pool:
-                if db_name.lower() not in DBPGInterface.HOST_POOL:
-                    DBPGInterface.HOST_POOL[db_name.lower()] = ConnectionPool(conn_str, min_size=PGCONN__min_conns,
+                if db_name.lower() not in HOST_POOL:
+                    HOST_POOL[db_name.lower()] = ConnectionPool(conn_str, min_size=PGCONN__min_conns,
                                                                               max_size=PGCONN__max_conns_jaaql_user, max_lifetime=60 * 30)
-                    DBPGInterface.HOST_USER = self.username
-                self.pg_pool = DBPGInterface.HOST_POOL[db_name.lower()]
+                    HOST_USER[db_name.lower()] = self.username
+                self.pg_pool = HOST_POOL[db_name.lower()]
             else:
                 self.pg_pool = ConnectionPool(conn_str, min_size=1, max_size=5)
         except OperationalError as ex:
@@ -66,7 +68,7 @@ class DBPGInterface(DBInterface):
     def get_conn(self):
         try:
             conn = self.pg_pool.getconn()
-            if DBPGInterface.HOST_USER != self.username and self.is_host_pool:
+            if HOST_USER[self.db_name.lower()] != self.username and self.is_host_pool:
                 with conn.cursor() as cursor:
                     cursor.execute("SET SESSION AUTHORIZATION '" + self.username + "';")
                     self.commit(conn)
@@ -79,7 +81,7 @@ class DBPGInterface(DBInterface):
         return conn
 
     def put_conn(self, conn):
-        if self.is_host_pool and DBPGInterface.HOST_USER != self.username:
+        if self.is_host_pool and HOST_USER[self.db_name.lower()] != self.username:
             with conn.cursor() as cursor:
                 cursor.execute("RESET SESSION AUTHORIZATION;")
                 self.commit(conn)
@@ -91,8 +93,8 @@ class DBPGInterface(DBInterface):
             print("Closing host pool")
 
             if self.is_host_pool:
-                DBPGInterface.HOST_POOL = None
-                DBPGInterface.HOST_USER = None
+                HOST_POOL = {}
+                HOST_USER = {}
                 print("Wiping host pool")
 
     def execute_query(self, conn, query, parameters=None):
@@ -100,7 +102,7 @@ class DBPGInterface(DBInterface):
             try:
                 with conn.cursor() as cursor:
                     do_prepare = False
-                    if DBPGInterface.HOST_USER != self.username and self.username != USERNAME__jaaql:
+                    if HOST_USER[self.db_name.lower()] != self.username and self.username != USERNAME__jaaql:
                         do_prepare = True
                         if not any([query.upper().startswith(ok_command) for ok_command in ALLOWABLE_COMMANDS]):
                             raise HttpStatusException(ERR__command_not_allowed)
